@@ -217,10 +217,10 @@ class MVPolyCube(mvpoly.base.MVPoly) :
         """
         return MVPolyCube(mvpoly.util.cube.int(self.coef, args))
 
-    def maxmodnb(self, *args) :
+    def maxmodnb(self, **kwargs) :
         """
         Maximum modulus of the polynomial on the unit ball, this
         method is only available if the :mod:`maxmodnb` package
         is installed (and that is in an early stage of development).
         """
-        return mvpoly.util.cube.maxmodnb(self.coef, *args)
+        return mvpoly.util.cube.maxmodnb(self.coef, **kwargs)
