@@ -48,6 +48,8 @@ class TestMVPolyCubeDtype(unittest.TestCase) :
         check_dtype(self, p, int)
         p.dtype = float
         check_dtype(self, p, float)
+        p.dtype = complex
+        check_dtype(self, p, complex)
 
 class TestMVPolyCubeOrder(unittest.TestCase) :
 
@@ -151,6 +153,14 @@ class TestMVPolyCubeMultiply(unittest.TestCase) :
                         "bad multiply:\n%s\n%s" % (repr(p1.coef), 
                                                    repr(p2.coef)))
 
+    def test_multiply_complex(self) :
+        x, y = MVPolyCube.monomials(2, dtype=complex)
+        p1 = (x + y)*(x + 1j*y)
+        p2 = x**2 + (1 + 1j)*x*y + 1j*y**2
+        self.assertTrue((p1.coef == p2.coef).all(),
+                        "bad multiply:\n%s\n%s" % (repr(p1.coef), 
+                                                   repr(p2.coef)))
+
 
 class TestMVPolyCubePower(unittest.TestCase) :
 
@@ -514,11 +524,26 @@ class TestMVPolyCubeMaxmodnb(unittest.TestCase) :
         eps = 1e-10
         x, y = MVPolyCube.monomials(2, dtype=complex)
         p = x**2 + 1
-        obtained = p.maxmodnb(eps)[0]
         expected = 2.0
+        obtained = p.maxmodnb(eps = eps)[0]
         self.assertTrue(abs(expected - obtained) < eps*expected, 
                         "bad maxmodnb %s" % repr(obtained))
-        
+
+    def test_maxmodnb_fifomax(self) :
+        x, y = MVPolyCube.monomials(2, dtype=complex)
+        p = x**2 + 1
+        self.assertRaises(RuntimeError, p.maxmodnb, fifomax = 3)
+
+    def test_maxmodnb_unknown_keyword(self) :
+        x, y = MVPolyCube.monomials(2, dtype=complex)
+        p = x**2 + 1
+        self.assertRaises(ValueError, p.maxmodnb, nosuchvar = 3)
+
+    def test_maxmodnb_no_positional_args(self) :
+        x, y = MVPolyCube.monomials(2, dtype=complex)
+        p = x**2 + 1
+        self.assertRaises(TypeError, p.maxmodnb, 3)
+
 
 if __name__ == '__main__':
     unittest.main()
